You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ph...@apache.org on 2013/02/07 21:12:15 UTC

svn commit: r1443695 - in /subversion/trunk/subversion/libsvn_wc: conflicts.c conflicts.h update_editor.c wc_db.c wc_db.h wc_db_private.h wc_db_update_move.c

Author: philip
Date: Thu Feb  7 20:12:15 2013
New Revision: 1443695

URL: http://svn.apache.org/r1443695
Log:
Rename some parameters and variables.

* subversion/libsvn_wc/conflicts.h
* subversion/libsvn_wc/conflicts.c
  (svn_wc__conflict_skel_add_tree_conflict,
   svn_wc__conflict_read_tree_conflict): Rename parameter.

* subversion/libsvn_wc/update_editor.c
  (open_root, check_tree_conflict): Rename some variables.

* subversion/libsvn_wc/wc_db.h
  (svn_wc__db_base_moved_to): Rename parameters.

* subversion/libsvn_wc/wc_db_private.h
  (svn_wc__db_op_depth_moved_to): Rename parameters.

* subversion/libsvn_wc/wc_db.c
  (svn_wc__db_op_depth_moved_to, svn_wc__db_base_moved_to): Rename parameters.

* subversion/libsvn_wc/wc_db_update_move.c
  (mark_tree_conflict): Rename parameter and variables.
  (check_tree_conflict, svn_wc__db_update_moved_away_conflict_victim,
   svn_wc__db_resolve_break_moved_away_internal): Rename variables.
  (get_tc_info, update_moved_away_conflict_victim): Rename parameter.

Modified:
    subversion/trunk/subversion/libsvn_wc/conflicts.c
    subversion/trunk/subversion/libsvn_wc/conflicts.h
    subversion/trunk/subversion/libsvn_wc/update_editor.c
    subversion/trunk/subversion/libsvn_wc/wc_db.c
    subversion/trunk/subversion/libsvn_wc/wc_db.h
    subversion/trunk/subversion/libsvn_wc/wc_db_private.h
    subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c

Modified: subversion/trunk/subversion/libsvn_wc/conflicts.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/conflicts.c?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/conflicts.c (original)
+++ subversion/trunk/subversion/libsvn_wc/conflicts.c Thu Feb  7 20:12:15 2013
@@ -537,7 +537,7 @@ svn_wc__conflict_skel_add_tree_conflict(
                                         const char *wri_abspath,
                                         svn_wc_conflict_reason_t local_change,
                                         svn_wc_conflict_action_t incoming_change,
-                                        const char *moved_away_op_root_abspath,
+                                        const char *move_src_op_root_abspath,
                                         apr_pool_t *result_pool,
                                         apr_pool_t *scratch_pool)
 {
@@ -550,21 +550,21 @@ svn_wc__conflict_skel_add_tree_conflict(
   SVN_ERR_ASSERT(!tree_conflict); /* ### Use proper error? */
 
   SVN_ERR_ASSERT(local_change == svn_wc_conflict_reason_moved_away
-                 || !moved_away_op_root_abspath); /* ### Use proper error? */
+                 || !move_src_op_root_abspath); /* ### Use proper error? */
 
   tree_conflict = svn_skel__make_empty_list(result_pool);
 
   if (local_change == svn_wc_conflict_reason_moved_away
-      && moved_away_op_root_abspath)
+      && move_src_op_root_abspath)
     {
-      const char *moved_away_op_root_relpath;
+      const char *move_src_op_root_relpath;
 
-      SVN_ERR(svn_wc__db_to_relpath(&moved_away_op_root_relpath,
+      SVN_ERR(svn_wc__db_to_relpath(&move_src_op_root_relpath,
                                     db, wri_abspath,
-                                    moved_away_op_root_abspath,
+                                    move_src_op_root_abspath,
                                     result_pool, scratch_pool));
 
-      svn_skel__prepend_str(moved_away_op_root_relpath, tree_conflict,
+      svn_skel__prepend_str(move_src_op_root_relpath, tree_conflict,
                             result_pool);
     }
 
@@ -933,7 +933,7 @@ svn_wc__conflict_read_prop_conflict(cons
 svn_error_t *
 svn_wc__conflict_read_tree_conflict(svn_wc_conflict_reason_t *local_change,
                                     svn_wc_conflict_action_t *incoming_change,
-                                    const char **moved_away_op_root_abspath,
+                                    const char **move_src_op_root_abspath,
                                     svn_wc__db_t *db,
                                     const char *wri_abspath,
                                     const svn_skel_t *conflict_skel,
@@ -983,21 +983,21 @@ svn_wc__conflict_read_tree_conflict(svn_
 
   c = c->next;
 
-  if (moved_away_op_root_abspath)
+  if (move_src_op_root_abspath)
     {
       /* Only set for update and switch tree conflicts */
       if (c && is_moved_away)
         {
-          const char *moved_away_op_root_relpath
+          const char *move_src_op_root_relpath
                             = apr_pstrmemdup(scratch_pool, c->data, c->len);
 
-          SVN_ERR(svn_wc__db_from_relpath(moved_away_op_root_abspath,
+          SVN_ERR(svn_wc__db_from_relpath(move_src_op_root_abspath,
                                           db, wri_abspath,
-                                          moved_away_op_root_relpath,
+                                          move_src_op_root_relpath,
                                           result_pool, scratch_pool));
         }
       else
-        *moved_away_op_root_abspath = NULL;
+        *move_src_op_root_abspath = NULL;
     }
 
   return SVN_NO_ERROR;

Modified: subversion/trunk/subversion/libsvn_wc/conflicts.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/conflicts.h?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/conflicts.h (original)
+++ subversion/trunk/subversion/libsvn_wc/conflicts.h Thu Feb  7 20:12:15 2013
@@ -201,8 +201,9 @@ svn_wc__conflict_skel_add_prop_conflict(
    It is an error to add another tree conflict to a conflict skel that
    already contains a tree conflict.
 
-   MOVED_AWAY_OP_ROOT_ABSPATH must be set when LOCAL_CHANGE is
-   svn_wc_conflict_reason_moved_away and NULL otherwise.  It should be
+   MOVE_SRC_OP_ROOT_ABSPATH must be set when LOCAL_CHANGE is
+   svn_wc_conflict_reason_moved_away and NULL otherwise and the operation
+   is svn_wc_operation_update or svn_wc_operation_switch.  It should be
    set to the op-root of the move-away unless the move is inside a
    delete in which case it should be set to the op-root of the delete
    (the delete can be a replace). So given:
@@ -210,8 +211,8 @@ svn_wc__conflict_skel_add_prop_conflict(
        A deleted and replaced
        A/B/C moved away (2)
        A/B deleted
-   MOVED_AWAY_OP_ROOT_ABSPATH should be A for a conflict associated
-   with (1), MOVED_AWAY_OP_ROOT_ABSPATH should be A/B for a conflict
+   MOVE_SRC_OP_ROOT_ABSPATH should be A for a conflict associated
+   with (1), MOVE_SRC_OP_ROOT_ABSPATH should be A/B for a conflict
    associated with (2).
 
    ### Is it an error to add a tree conflict to any existing conflict?
@@ -224,7 +225,7 @@ svn_wc__conflict_skel_add_tree_conflict(
                                         const char *wri_abspath,
                                         svn_wc_conflict_reason_t local_change,
                                         svn_wc_conflict_action_t incoming_change,
-                                        const char *moved_away_op_root_abspath,
+                                        const char *move_src_op_root_abspath,
                                         apr_pool_t *result_pool,
                                         apr_pool_t *scratch_pool);
 
@@ -355,7 +356,7 @@ svn_wc__conflict_read_prop_conflict(cons
 svn_error_t *
 svn_wc__conflict_read_tree_conflict(svn_wc_conflict_reason_t *local_change,
                                     svn_wc_conflict_action_t *incoming_change,
-                                    const char **moved_away_op_root_abspath,
+                                    const char **move_src_op_root_abspath,
                                     svn_wc__db_t *db,
                                     const char *wri_abspath,
                                     const svn_skel_t *conflict_skel,

Modified: subversion/trunk/subversion/libsvn_wc/update_editor.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/update_editor.c?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/update_editor.c (original)
+++ subversion/trunk/subversion/libsvn_wc/update_editor.c Thu Feb  7 20:12:15 2013
@@ -1241,12 +1241,12 @@ open_root(void *edit_baton,
 
   if (have_work)
     {
-      const char *moved_away_root_abspath;
+      const char *move_src_root_abspath;
 
-      SVN_ERR(svn_wc__db_base_moved_to(NULL, NULL, &moved_away_root_abspath,
+      SVN_ERR(svn_wc__db_base_moved_to(NULL, NULL, &move_src_root_abspath,
                                        NULL, eb->db, db->local_abspath,
                                        pool, pool));
-      if (moved_away_root_abspath)
+      if (move_src_root_abspath)
         {
           /* This is an update anchored inside a move. We need to
              raise a move-edit tree-conflict on the move root to
@@ -1254,26 +1254,26 @@ open_root(void *edit_baton,
           svn_skel_t *tree_conflict = svn_wc__conflict_skel_create(pool);
 
           SVN_ERR(svn_wc__conflict_skel_add_tree_conflict(
-                    tree_conflict, eb->db, moved_away_root_abspath,
+                    tree_conflict, eb->db, move_src_root_abspath,
                     svn_wc_conflict_reason_moved_away,
                     svn_wc_conflict_action_edit,
-                    moved_away_root_abspath, pool, pool));
+                    move_src_root_abspath, pool, pool));
 
-          if (strcmp(db->local_abspath, moved_away_root_abspath))
+          if (strcmp(db->local_abspath, move_src_root_abspath))
             {
               /* This is some parent of the edit root, we won't be
                  handling it again so raise the conflict now. */
               SVN_ERR(complete_conflict(tree_conflict, eb,
-                                        moved_away_root_abspath,
+                                        move_src_root_abspath,
                                         db->old_repos_relpath,
                                         db->old_revision, db->new_relpath,
                                         svn_node_dir, svn_node_dir,
                                         pool, pool));
               SVN_ERR(svn_wc__db_op_mark_conflict(eb->db,
-                                                  moved_away_root_abspath,
+                                                  move_src_root_abspath,
                                                   tree_conflict,
                                                   NULL, pool));
-              do_notification(eb, moved_away_root_abspath, svn_node_dir,
+              do_notification(eb, move_src_root_abspath, svn_node_dir,
                               svn_wc_notify_tree_conflict, pool);
             }
           else
@@ -1455,7 +1455,7 @@ check_tree_conflict(svn_skel_t **pconfli
   svn_wc_conflict_reason_t reason = SVN_WC_CONFLICT_REASON_NONE;
   svn_boolean_t modified = FALSE;
   svn_boolean_t all_mods_are_deletes = FALSE;
-  const char *moved_away_op_root_abspath = NULL;
+  const char *move_src_op_root_abspath = NULL;
 
   *pconflict = NULL;
 
@@ -1495,10 +1495,10 @@ check_tree_conflict(svn_skel_t **pconfli
           {
             /* The node is locally replaced but could also be moved-away. */
             SVN_ERR(svn_wc__db_base_moved_to(NULL, NULL, NULL,
-                                             &moved_away_op_root_abspath,
+                                             &move_src_op_root_abspath,
                                              eb->db, local_abspath,
                                              scratch_pool, scratch_pool));
-            if (moved_away_op_root_abspath)
+            if (move_src_op_root_abspath)
               reason = svn_wc_conflict_reason_moved_away;
             else
               reason = svn_wc_conflict_reason_replaced;
@@ -1509,10 +1509,10 @@ check_tree_conflict(svn_skel_t **pconfli
       case svn_wc__db_status_deleted:
         {
           SVN_ERR(svn_wc__db_base_moved_to(NULL, NULL, NULL,
-                                           &moved_away_op_root_abspath,
+                                           &move_src_op_root_abspath,
                                            eb->db, local_abspath,
                                            scratch_pool, scratch_pool));
-          if (moved_away_op_root_abspath)
+          if (move_src_op_root_abspath)
             reason = svn_wc_conflict_reason_moved_away;
           else
             reason = svn_wc_conflict_reason_deleted;
@@ -1627,7 +1627,7 @@ check_tree_conflict(svn_skel_t **pconfli
                                                   eb->db, local_abspath,
                                                   reason,
                                                   action,
-                                                  moved_away_op_root_abspath,
+                                                  move_src_op_root_abspath,
                                                   result_pool, scratch_pool));
 
   return SVN_NO_ERROR;

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.c?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db.h (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.h Thu Feb  7 20:12:15 2013
@@ -3271,11 +3271,16 @@ svn_wc__db_update_moved_away_conflict_vi
                                              apr_pool_t *result_pool,
                                              apr_pool_t *scratch_pool);
 
+/* LOCAL_ABSPATH is moved to MOVE_DST_ABSPATH.  MOVE_SRC_ROOT_ABSPATH
+ * is the root of the move to MOVE_DST_OP_ROOT_ABSPATH.
+ * MOVE_SRC_OP_ROOT_ABSPATH is the op-root of the move; it's the same
+ * as MOVE_SRC_ROOT_ABSPATH except for moves inside deletes when it is
+ * the op-root of the delete. */
 svn_error_t *
-svn_wc__db_base_moved_to(const char **moved_to_abspath,
-                         const char **moved_to_op_root_abspath,
-                         const char **moved_away_op_root_abspath,
-                         const char **op_root_abspath,
+svn_wc__db_base_moved_to(const char **move_dst_abspath,
+                         const char **move_dst_op_root_abspath,
+                         const char **move_src_root_abspath,
+                         const char **move_src_op_root_abspath,
                          svn_wc__db_t *db,
                          const char *local_abspath,
                          apr_pool_t *result_pool,

Modified: subversion/trunk/subversion/libsvn_wc/wc_db_private.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db_private.h?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db_private.h (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db_private.h Thu Feb  7 20:12:15 2013
@@ -410,10 +410,10 @@ svn_wc__db_retract_parent_delete(svn_wc_
                                  apr_pool_t *scratch_pool);
 
 svn_error_t *
-svn_wc__db_op_depth_moved_to(const char **moved_to_relpath,
-                             const char **moved_to_op_root_relpath,
-                             const char **moved_away_root_relpath,
-                             const char **op_root_relpath,
+svn_wc__db_op_depth_moved_to(const char **move_dst_relpath,
+                             const char **move_dst_op_root_relpath,
+                             const char **move_src_root_relpath,
+                             const char **move_src_op_root_relpath,
                              int op_depth,
                              svn_wc__db_wcroot_t *wcroot,
                              const char *local_relpath,

Modified: subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c Thu Feb  7 20:12:15 2013
@@ -219,16 +219,16 @@ mark_tree_conflict(struct tc_editor_bato
                    const char *old_repos_relpath,
                    svn_wc_conflict_reason_t reason,
                    svn_wc_conflict_action_t action,
-                   const char *moved_away_op_root_relpath,
+                   const char *move_src_op_root_relpath,
                    apr_pool_t *scratch_pool)
 {
   svn_error_t *err;
   svn_skel_t *conflict;
   svn_wc_conflict_version_t *old_version, *new_version;
-  const char *moved_away_op_root_abspath
-    = moved_away_op_root_relpath
+  const char *move_src_op_root_abspath
+    = move_src_op_root_relpath
     ? svn_dirent_join(b->wcroot->abspath,
-                      moved_away_op_root_relpath, scratch_pool)
+                      move_src_op_root_relpath, scratch_pool)
     : NULL;
   const char *old_repos_relpath_part
     = old_repos_relpath
@@ -278,7 +278,7 @@ mark_tree_conflict(struct tc_editor_bato
           if (reason != existing_reason
               || action != existing_action
               || (reason == svn_wc_conflict_reason_moved_away
-                  && strcmp(moved_away_op_root_relpath,
+                  && strcmp(move_src_op_root_relpath,
                             svn_dirent_skip_ancestor(b->wcroot->abspath,
                                                      existing_abspath))))
             return svn_error_createf(SVN_ERR_WC_CONFLICT_RESOLVER_FAILURE, NULL,
@@ -304,7 +304,7 @@ mark_tree_conflict(struct tc_editor_bato
                                      scratch_pool),
                      reason,
                      action,
-                     moved_away_op_root_abspath,
+                     move_src_op_root_abspath,
                      scratch_pool,
                      scratch_pool));
 
@@ -368,8 +368,8 @@ check_tree_conflict(svn_boolean_t *is_co
   int dst_op_depth = relpath_depth(b->move_root_dst_relpath);
   int op_depth;
   const char *conflict_root_relpath = local_relpath;
-  const char *moved_to_relpath, *moved_to_op_root_relpath;
-  const char *moved_away_root_relpath, *moved_away_op_root_relpath;
+  const char *move_dst_relpath, *dummy1;
+  const char *dummy2, *move_src_op_root_relpath;
 
   if (b->conflict_root_relpath)
     {
@@ -409,20 +409,20 @@ check_tree_conflict(svn_boolean_t *is_co
       action = svn_wc_conflict_action_edit;
     }
 
-  SVN_ERR(svn_wc__db_op_depth_moved_to(&moved_to_relpath,
-                                       &moved_to_op_root_relpath,
-                                       &moved_away_root_relpath,
-                                       &moved_away_op_root_relpath,
+  SVN_ERR(svn_wc__db_op_depth_moved_to(&move_dst_relpath,
+                                       &dummy1,
+                                       &dummy2,
+                                       &move_src_op_root_relpath,
                                        dst_op_depth,
                                        b->wcroot, conflict_root_relpath,
                                        scratch_pool, scratch_pool));
 
   SVN_ERR(mark_tree_conflict(b, conflict_root_relpath, old_kind, new_kind,
                              old_repos_relpath,
-                             (moved_to_relpath
+                             (move_dst_relpath
                               ? svn_wc_conflict_reason_moved_away
                               : svn_wc_conflict_reason_deleted),
-                             action, moved_away_op_root_relpath,
+                             action, move_src_op_root_relpath,
                              scratch_pool));
   if (b->notify_func)
     SVN_ERR(update_move_list_add(b->wcroot, local_relpath,
@@ -1301,7 +1301,7 @@ static svn_error_t *
 get_tc_info(svn_wc_operation_t *operation,
             svn_wc_conflict_reason_t *local_change,
             svn_wc_conflict_action_t *incoming_change,
-            const char **moved_away_op_root_abspath,
+            const char **move_src_op_root_abspath,
             svn_wc_conflict_version_t **old_version,
             svn_wc_conflict_version_t **new_version,
             svn_wc__db_t *db,
@@ -1346,7 +1346,7 @@ get_tc_info(svn_wc_operation_t *operatio
 
   SVN_ERR(svn_wc__conflict_read_tree_conflict(local_change,
                                               incoming_change,
-                                              moved_away_op_root_abspath,
+                                              move_src_op_root_abspath,
                                               db, src_abspath,
                                               conflict_skel, scratch_pool,
                                               scratch_pool));
@@ -1779,7 +1779,7 @@ update_moved_away_conflict_victim(svn_sk
                                   svn_wc_operation_t operation,
                                   svn_wc_conflict_reason_t local_change,
                                   svn_wc_conflict_action_t incoming_change,
-                                  const char *moved_away_op_root_relpath,
+                                  const char *move_src_op_root_relpath,
                                   svn_wc_conflict_version_t *old_version,
                                   svn_wc_conflict_version_t *new_version,
                                   svn_wc_notify_func2_t notify_func,
@@ -1802,7 +1802,7 @@ update_moved_away_conflict_victim(svn_sk
   tc_editor_baton = apr_pcalloc(scratch_pool, sizeof(*tc_editor_baton));
   SVN_ERR(svn_wc__db_op_depth_moved_to(
             &dummy1, &tc_editor_baton->move_root_dst_relpath, &dummy2, &dummy3,
-            relpath_depth(moved_away_op_root_relpath) - 1,
+            relpath_depth(move_src_op_root_relpath) - 1,
             wcroot, victim_relpath, scratch_pool, scratch_pool));
   if (tc_editor_baton->move_root_dst_relpath == NULL)
     return svn_error_createf(SVN_ERR_WC_CONFLICT_RESOLVER_FAILURE, NULL,
@@ -1821,12 +1821,11 @@ update_moved_away_conflict_victim(svn_sk
   tc_editor_baton->notify_baton = notify_baton;
   tc_editor_baton->result_pool = result_pool;
 
-  /* ### TODO get from svn_wc__db_op_depth_moved_to? */
   SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
                                     STMT_SELECT_HIGHEST_WORKING_NODE));
   SVN_ERR(svn_sqlite__bindf(stmt, "isd", wcroot->wc_id,
-                            moved_away_op_root_relpath,
-                            relpath_depth(moved_away_op_root_relpath)));
+                            move_src_op_root_relpath,
+                            relpath_depth(move_src_op_root_relpath)));
   SVN_ERR(svn_sqlite__step(&have_row, stmt));
   if (have_row)
     src_op_depth = svn_sqlite__column_int(stmt, 0);
@@ -1886,10 +1885,10 @@ svn_wc__db_update_moved_away_conflict_vi
   svn_wc_conflict_action_t incoming_change;
   svn_wc_conflict_version_t *old_version;
   svn_wc_conflict_version_t *new_version;
-  const char *moved_away_op_root_abspath, *moved_away_op_root_relpath;
+  const char *move_src_op_root_abspath, *move_src_op_root_relpath;
 
   SVN_ERR(get_tc_info(&operation, &local_change, &incoming_change,
-                      &moved_away_op_root_abspath,
+                      &move_src_op_root_abspath,
                       &old_version, &new_version,
                       db, victim_abspath,
                       scratch_pool, scratch_pool));
@@ -1899,14 +1898,14 @@ svn_wc__db_update_moved_away_conflict_vi
                                                 scratch_pool, scratch_pool));
   VERIFY_USABLE_WCROOT(wcroot);
 
-  moved_away_op_root_relpath
-    = svn_dirent_skip_ancestor(wcroot->abspath, moved_away_op_root_abspath);
+  move_src_op_root_relpath
+    = svn_dirent_skip_ancestor(wcroot->abspath, move_src_op_root_abspath);
 
   SVN_WC__DB_WITH_TXN(
     update_moved_away_conflict_victim(
       work_items, db, wcroot, local_relpath,
       operation, local_change, incoming_change,
-      moved_away_op_root_relpath,
+      move_src_op_root_relpath,
       old_version, new_version,
       notify_func, notify_baton,
       cancel_func, cancel_baton,
@@ -2113,30 +2112,30 @@ svn_wc__db_resolve_break_moved_away_inte
                                              const char *local_relpath,
                                              apr_pool_t *scratch_pool)
 {
-  const char *dummy, *moved_to_op_root_relpath;
-  const char *moved_away_root_relpath, *op_root_relpath;
+  const char *dummy1, *move_dst_op_root_relpath;
+  const char *dummy2, *move_src_op_root_relpath;
   svn_sqlite__stmt_t *stmt;
   int dst_op_depth;
 
-  SVN_ERR(svn_wc__db_op_depth_moved_to(&dummy, &moved_to_op_root_relpath,
-                                       &moved_away_root_relpath,
-                                       &op_root_relpath,
+  SVN_ERR(svn_wc__db_op_depth_moved_to(&dummy1, &move_dst_op_root_relpath,
+                                       &dummy2,
+                                       &move_src_op_root_relpath,
                                        relpath_depth(local_relpath) - 1,
                                        wcroot, local_relpath,
                                        scratch_pool, scratch_pool));
-  dst_op_depth = relpath_depth(moved_to_op_root_relpath);
+  dst_op_depth = relpath_depth(move_dst_op_root_relpath);
 
   SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
                                     STMT_CLEAR_MOVED_TO_RELPATH));
   SVN_ERR(svn_sqlite__bindf(stmt, "isd", wcroot->wc_id, local_relpath,
-                            relpath_depth(op_root_relpath)));
+                            relpath_depth(move_src_op_root_relpath)));
   SVN_ERR(svn_sqlite__step_done(stmt));
 
   /* This statement clears moved_here. */
   SVN_ERR(svn_sqlite__get_statement(&stmt, wcroot->sdb,
                                     STMT_UPDATE_OP_DEPTH_RECURSIVE));
   SVN_ERR(svn_sqlite__bindf(stmt, "isdd", wcroot->wc_id,
-                            moved_to_op_root_relpath,
+                            move_dst_op_root_relpath,
                             dst_op_depth, dst_op_depth));
   SVN_ERR(svn_sqlite__step_done(stmt));
--- subversion/trunk/subversion/libsvn_wc/wc_db.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.c Thu Feb  7 20:12:15 2013
@@ -11555,28 +11555,28 @@ svn_wc__db_follow_moved_to(apr_array_hea
    examining the lowest working node above OP_DEPTH.  The output paths
    are NULL if there is no move, otherwise:
 
    *MOVED_TO_RELPATH: the moved-to destination of LOCAL_RELPATH.
 
-   *MOVED_TO_OP_ROOT_RELPATH: the moved-to destination of the root of
-   the move of LOCAL_RELPATH. This may be equal to *MOVED_TO_RELPATH
+   *MOVE_DST_OP_ROOT_RELPATH: the moved-to destination of the root of
+   the move of LOCAL_RELPATH. This may be equal to *MOVE_DST_RELPATH
    if LOCAL_RELPATH is the root of the move.
 
-   *MOVED_AWAY_ROOT_RELPATH: the root of the move source.  For
-   moves inside a delete this will be different from *OP_ROOT_RELPATH.
+   *MOVE_SRC_ROOT_RELPATH: the root of the move source.  For moves
+   inside a delete this will be different from *MOVE_SRC_OP_ROOT_RELPATH.
 
-   *OP_ROOT_RELPATH: the root of the source layer that contains the
-   move.  For moves inside deletes this is the root of the delete, for
-   other moves this is the root of the move.
+   *MOVE_SRC_OP_ROOT_RELPATH: the root of the source layer that
+   contains the move.  For moves inside deletes this is the root of
+   the delete, for other moves this is the root of the move.
 
    Given a path A/B/C with A/B moved to X then for A/B/C
 
-     MOVED_TO_RELPATH is X/C
-     MOVED_TO_OP_ROOT_RELPATH is X
-     MOVED_AWAY_OP_ROOT_RELPATH is A/B
-     OP_ROOT_RELPATH is A/B
+     MOVE_DST_RELPATH is X/C
+     MOVE_DST_OP_ROOT_RELPATH is X
+     MOVE_SRC_ROOT_RELPATH is A/B
+     MOVE_SRC_OP_ROOT_RELPATH is A/B
 
-   If A is then deleted the MOVED_TO_RELPATH, MOVED_TO_OP_ROOT_RELPATH
-   and MOVED_AWAY_ROOT_RELPATH remain the same but OP_ROOT_RELPATH
+   If A is then deleted the MOVE_DST_RELPATH, MOVE_DST_OP_ROOT_RELPATH
+   and MOVE_SRC_ROOT_RELPATH remain the same but MOVE_SRC_OP_ROOT_RELPATH
    changes to A.
 
    ### Think about combining with scan_deletion?  Also with
@@ -11584,10 +11584,10 @@ svn_wc__db_follow_moved_to(apr_array_hea
    ### return the op-root of the move source, i.e. A/B in the example
    ### above?  */
 svn_error_t *
-svn_wc__db_op_depth_moved_to(const char **moved_to_relpath,
-                             const char **moved_to_op_root_relpath,
-                             const char **moved_away_root_relpath,
-                             const char **op_root_relpath,
+svn_wc__db_op_depth_moved_to(const char **move_dst_relpath,
+                             const char **move_dst_op_root_relpath,
+                             const char **move_src_root_relpath,
+                             const char **move_src_op_root_relpath,
                              int op_depth,
                              svn_wc__db_wcroot_t *wcroot,
                              const char *local_relpath,
@@ -11599,8 +11599,8 @@ svn_wc__db_op_depth_moved_to(const char 
   int delete_op_depth;
   const char *relpath = local_relpath;
 
-  *moved_to_relpath = *moved_to_op_root_relpath = NULL;
-  *moved_away_root_relpath = *op_root_relpath = NULL;
+  *move_dst_relpath = *move_dst_op_root_relpath = NULL;
+  *move_src_root_relpath = *move_src_op_root_relpath = NULL;
 
   do
     {
@@ -11611,27 +11611,27 @@ svn_wc__db_op_depth_moved_to(const char 
       if (have_row)
         {
           delete_op_depth = svn_sqlite__column_int(stmt, 0);
-          *moved_to_op_root_relpath = svn_sqlite__column_text(stmt, 3,
+          *move_dst_op_root_relpath = svn_sqlite__column_text(stmt, 3,
                                                               result_pool);
-          if (*moved_to_op_root_relpath)
-            *moved_away_root_relpath = apr_pstrdup(result_pool, relpath);
+          if (*move_dst_op_root_relpath)
+            *move_src_root_relpath = apr_pstrdup(result_pool, relpath);
         }
       SVN_ERR(svn_sqlite__reset(stmt));
-      if (!*moved_to_op_root_relpath)
+      if (!*move_dst_op_root_relpath)
         relpath = svn_relpath_dirname(relpath, scratch_pool);
     }
-  while (!*moved_to_op_root_relpath
+  while (!*move_dst_op_root_relpath
         && have_row && delete_op_depth <= relpath_depth(relpath));
 
-  if (*moved_to_op_root_relpath)
+  if (*move_dst_op_root_relpath)
     {
-      *moved_to_relpath
-        = svn_relpath_join(*moved_to_op_root_relpath,
+      *move_dst_relpath
+        = svn_relpath_join(*move_dst_op_root_relpath,
                            svn_relpath_skip_ancestor(relpath, local_relpath),
                            result_pool);
       while (delete_op_depth < relpath_depth(relpath))
         relpath = svn_relpath_dirname(relpath, scratch_pool);
-      *op_root_relpath = apr_pstrdup(result_pool, relpath);
+      *move_src_op_root_relpath = apr_pstrdup(result_pool, relpath);
     }
 
   return SVN_NO_ERROR;
@@ -11641,10 +11641,10 @@ svn_wc__db_op_depth_moved_to(const char 
    svn_wc__db_op_depth_moved_to with the op-depth hard-coded to
    BASE. */
 svn_error_t *
-svn_wc__db_base_moved_to(const char **moved_to_abspath,
-                         const char **moved_to_op_root_abspath,
-                         const char **moved_away_root_abspath,
-                         const char **op_root_abspath,
+svn_wc__db_base_moved_to(const char **move_dst_abspath,
+                         const char **move_dst_op_root_abspath,
+                         const char **move_src_root_abspath,
+                         const char **move_src_op_root_abspath,
                          svn_wc__db_t *db,
                          const char *local_abspath,
                          apr_pool_t *result_pool,
@@ -11652,8 +11652,8 @@ svn_wc__db_base_moved_to(const char **mo
 {
   svn_wc__db_wcroot_t *wcroot;
   const char *local_relpath;
-  const char *moved_to_relpath, *moved_to_op_root_relpath;
-  const char *moved_away_root_relpath, *op_root_relpath;
+  const char *move_dst_relpath, *move_dst_op_root_relpath;
+  const char *move_src_root_relpath, *move_src_op_root_relpath;
 
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
@@ -11661,38 +11661,37 @@ svn_wc__db_base_moved_to(const char **mo
                               local_abspath, scratch_pool, scratch_pool));
   VERIFY_USABLE_WCROOT(wcroot);
 
-  SVN_WC__DB_WITH_TXN(svn_wc__db_op_depth_moved_to(&moved_to_relpath,
-                                                   &moved_to_op_root_relpath,
-                                                   &moved_away_root_relpath,
-                                                   &op_root_relpath,
+  SVN_WC__DB_WITH_TXN(svn_wc__db_op_depth_moved_to(&move_dst_relpath,
+                                                   &move_dst_op_root_relpath,
+                                                   &move_src_root_relpath,
+                                                   &move_src_op_root_relpath,
                                                    0 /* BASE op-depth */,
                                                    wcroot, local_relpath,
                                                    scratch_pool, scratch_pool),
                       wcroot);
 
-  if (moved_to_abspath)
-    *moved_to_abspath
-      = moved_to_relpath
-      ? svn_dirent_join(wcroot->abspath, moved_to_relpath, result_pool)
+  if (move_dst_abspath)
+    *move_dst_abspath
+      = move_dst_relpath
+      ? svn_dirent_join(wcroot->abspath, move_dst_relpath, result_pool)
       : NULL;
 
-  if (moved_to_op_root_abspath)
-    *moved_to_op_root_abspath
-      = moved_to_op_root_relpath
-      ? svn_dirent_join(wcroot->abspath, moved_to_relpath, result_pool)
+  if (move_dst_op_root_abspath)
+    *move_dst_op_root_abspath
+      = move_dst_op_root_relpath
+      ? svn_dirent_join(wcroot->abspath, move_dst_op_root_relpath, result_pool)
       : NULL;
 
-  if (moved_away_root_abspath)
-    *moved_away_root_abspath
-      = moved_away_root_relpath
-      ? svn_dirent_join(wcroot->abspath, moved_away_root_relpath,
-                        result_pool)
+  if (move_src_root_abspath)
+    *move_src_root_abspath
+      = move_src_root_relpath
+      ? svn_dirent_join(wcroot->abspath, move_src_root_relpath, result_pool)
       : NULL;
 
-  if (op_root_abspath)
-    *op_root_abspath
-      = op_root_relpath
-      ? svn_dirent_join(wcroot->abspath, op_root_relpath, result_pool)
+  if (move_src_op_root_abspath)
+    *move_src_op_root_abspath
+      = move_src_op_root_relpath
+      ? svn_dirent_join(wcroot->abspath, move_src_op_root_relpath, result_pool)
       : NULL;
 
   return SVN_NO_ERROR;
@@ -11555,28 +11555,28 @@ svn_wc__db_follow_moved_to(apr_array_hea
    are NULL if there is no move, otherwise:
 
-   *MOVED_TO_RELPATH: the moved-to destination of LOCAL_RELPATH.
+   *MOVE_DST_RELPATH: the moved-to destination of LOCAL_RELPATH.
 

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.h?rev=1443695&r1=1443694&r2=1443695&view=diff
==============================================================================